You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pinot.apache.org by jl...@apache.org on 2020/03/27 02:59:20 UTC

[incubator-pinot] 01/01: Add logic

This is an automated email from the ASF dual-hosted git repository.

jlli pushed a commit to branch jfrog-bintray
in repository https://gitbox.apache.org/repos/asf/incubator-pinot.git

commit bb99da292ec3d3fc10c44cdf31e5a285f7fcf3b2
Author: jackjlli <jl...@linkedin.com>
AuthorDate: Thu Mar 26 15:17:52 2020 -0700

    Add logic
---
 .travis.yml                                         |  4 +++-
 .travis_install.sh                                  |  6 +++---
 .travis_nightly_build.sh                            | 19 +++++++++++--------
 ...tly_build.sh => .travis_set_deploy_build_opts.sh | 21 +++++++--------------
 .travis_test.sh                                     |  6 +++---
 5 files changed, 27 insertions(+), 29 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 36e0082..9ee45dd 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -6,7 +6,9 @@ before_install:
   - mkdir -p ~/bin && curl -sSL -o ~/bin/jq https://github.com/stedolan/jq/releases/download/jq-1.5/jq-linux64 && chmod +x ~/bin/jq
   - export PATH=$PATH:~/bin
   - jq --version
-  - export DEV_VERSION="-dev-${TRAVIS_BUILD_NUMBER}"
+  - source ./.travis_set_deploy_build_opts.sh
+#  - export DEV_VERSION="-dev-${TRAVIS_BUILD_NUMBER}"
+#  - export DEPLOY_BUILD_OPTS="-Dsha1=-dev-${TRAVIS_BUILD_NUMBER}"
 
 jdk:
   - oraclejdk8
diff --git a/.travis_install.sh b/.travis_install.sh
index f6e9730..c319ecb 100755
--- a/.travis_install.sh
+++ b/.travis_install.sh
@@ -53,7 +53,7 @@ if [ $noThirdEyeChange -ne 0 ]; then
   echo "No ThirdEye changes"
   if [ "$TRAVIS_JDK_VERSION" != 'oraclejdk8' ]; then
     # JDK 11 prints more logs exceeding Travis limits.
-    mvn clean install -B -DskipTests=true -Pbin-dist -Dmaven.javadoc.skip=true -Dsha1="${DEV_VERSION}" ${KAFKA_BUILD_OPTS} > /tmp/mvn_build_log
+    mvn clean install -B -DskipTests=true -Pbin-dist -Dmaven.javadoc.skip=true ${DEPLOY_BUILD_OPTS} ${KAFKA_BUILD_OPTS} > /tmp/mvn_build_log
     if [ $? -eq 0 ]; then
       exit 0
     else
@@ -61,7 +61,7 @@ if [ $noThirdEyeChange -ne 0 ]; then
       exit 1
     fi
   else
-    mvn clean install -B -DskipTests=true -Pbin-dist -Dmaven.javadoc.skip=true -Dsha1="${DEV_VERSION}" ${KAFKA_BUILD_OPTS} || exit $?
+    mvn clean install -B -DskipTests=true -Pbin-dist -Dmaven.javadoc.skip=true ${DEPLOY_BUILD_OPTS} ${KAFKA_BUILD_OPTS} || exit $?
   fi
 fi
 
@@ -69,7 +69,7 @@ fi
 if [ $noThirdEyeChange -eq 0 ]; then
   echo "Partial Pinot build"
   echo "ThirdEye changes only"
-  mvn install -B -DskipTests -Dmaven.javadoc.skip=true -Dassembly.skipAssembly=true -Dsha1="${DEV_VERSION}" -pl pinot-common,pinot-core,pinot-api -am
+  mvn install -B -DskipTests -Dmaven.javadoc.skip=true -Dassembly.skipAssembly=true ${DEPLOY_BUILD_OPTS} -pl pinot-common,pinot-core,pinot-api -am
   cd thirdeye/thirdeye-hadoop
   mvn clean compile -B -DskipTests
   cd ../..
diff --git a/.travis_nightly_build.sh b/.travis_set_deploy_build_opts.sh
similarity index 57%
copy from .travis_nightly_build.sh
copy to .travis_set_deploy_build_opts.sh
index caa6eb7..02e674c 100755
--- a/.travis_nightly_build.sh
+++ b/.travis_set_deploy_build_opts.sh
@@ -18,17 +18,10 @@
 # under the License.
 #
 
-# deploy the release to bintray
-#if [ "$TRAVIS_EVENT_TYPE" = "cron" ]; then
-#  echo "Deploying to bintray"
-#  mvn clean deploy --settings .ci.settings.xml -Dsha1="${DEV_VERSION}" -DskipTests -e -DretryFailedDeploymentCount=5
-#fi
-echo "Deploying to bintray"
-
-BUILD_VERSION=$(grep -E "<revision>(.*)</revision>" pom.xml | cut -d'>' -f2 | cut -d'<' -f1)
-echo "Current build version: $BUILD_VERSION${DEV_VERSION}"
-mvn versions:set -DnewVersion="$BUILD_VERSION${DEV_VERSION}"
-mvn versions:commit
-
-# Deploy to bintray
-mvn deploy -s .ci.settings.xml -DskipTests -DretryFailedDeploymentCount=5
+# if [ "$TRAVIS_EVENT_TYPE" = "cron" ]; then
+if true ; then
+  export DEV_VERSION="-dev-${TRAVIS_BUILD_NUMBER}"
+  export DEPLOY_BUILD_OPTS="-Dsha1=-dev-${TRAVIS_BUILD_NUMBER}"
+else
+  export DEPLOY_BUILD_OPTS=""
+fi
diff --git a/.travis_test.sh b/.travis_test.sh
index 88eb23d..a61f93c 100755
--- a/.travis_test.sh
+++ b/.travis_test.sh
@@ -36,7 +36,7 @@ if [ $? -eq 0 ]; then
   fi
 
   cd thirdeye
-  mvn test -B -Dsha1="${DEV_VERSION}"
+  mvn test -B ${DEPLOY_BUILD_OPTS}
   failed=$?
   # Remove Pinot/ThirdEye files from local Maven repository to avoid a useless cache rebuild
   rm -rf ~/.m2/repository/com/linkedin/pinot ~/.m2/repository/com/linkedin/thirdeye
@@ -64,12 +64,12 @@ fi
 
 # Only run integration tests if needed
 if [ "$RUN_INTEGRATION_TESTS" != 'false' ]; then
-  mvn test -B -Dsha1="${DEV_VERSION}" -P travis,travis-integration-tests-only ${KAFKA_BUILD_OPTS}
+  mvn test -B -P travis,travis-integration-tests-only ${DEPLOY_BUILD_OPTS} ${KAFKA_BUILD_OPTS}
   if [ $? -eq 0 ]; then
     passed=1
   fi
 else
-  mvn test -B -Dsha1="${DEV_VERSION}" -P travis,travis-no-integration-tests ${KAFKA_BUILD_OPTS}
+  mvn test -B -P travis,travis-no-integration-tests ${DEPLOY_BUILD_OPTS} ${KAFKA_BUILD_OPTS}
   if [ $? -eq 0 ]; then
     passed=1
   fi


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@pinot.apache.org
For additional commands, e-mail: commits-help@pinot.apache.org
diff --git a/.travis_nightly_build.sh b/.travis_nightly_build.sh
index caa6eb7..ee09bc0 100755
--- a/.travis_nightly_build.sh
+++ b/.travis_nightly_build.sh
@@ -21,14 +21,17 @@
 # deploy the release to bintray
 #if [ "$TRAVIS_EVENT_TYPE" = "cron" ]; then
 #  echo "Deploying to bintray"
 #  mvn clean deploy --settings .ci.settings.xml -Dsha1="${DEV_VERSION}" -DskipTests -e -DretryFailedDeploymentCount=5
 #fi
-echo "Deploying to bintray"
 
-BUILD_VERSION=$(grep -E "<revision>(.*)</revision>" pom.xml | cut -d'>' -f2 | cut -d'<' -f1)
-echo "Current build version: $BUILD_VERSION${DEV_VERSION}"
-mvn versions:set -DnewVersion="$BUILD_VERSION${DEV_VERSION}"
-mvn versions:commit
+if [ -n "${DEPLOY_BUILD_OPTS}" ]; then
+  echo "Deploying to bintray"
 
-# Deploy to bintray
-mvn deploy -s .ci.settings.xml -DskipTests -DretryFailedDeploymentCount=5
+  BUILD_VERSION=$(grep -E "<revision>(.*)</revision>" pom.xml | cut -d'>' -f2 | cut -d'<' -f1)
+  echo "Current build version: $BUILD_VERSION${DEV_VERSION}"
+  mvn versions:set -DnewVersion="$BUILD_VERSION${DEV_VERSION}" -q -B
+  mvn versions:commit -q -B
+
+  # Deploy to bintray
+  mvn deploy -s .ci.settings.xml -DskipTests -DretryFailedDeploymentCount=5
+fi
@@ -21,14 +21,17 @@
 #if [ "$TRAVIS_EVENT_TYPE" = "cron" ]; then
 #  echo "Deploying to bintray"
-#  mvn clean deploy --settings .ci.settings.xml -Dsha1="${DEV_VERSION}" -DskipTests -e -DretryFailedDeploymentCount=5
+#  mvn clean deploy --settings .ci.settings.xml ${DEPLOY_BUILD_OPTS} -DskipTests -e -DretryFailedDeploymentCount=5
 #fi